==> haskell-decimal-0.5.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Decimal
version: 0.5.1
id: Decimal-0.5.1-H3X57wSTHjwGTtZt62YXYD
key: Decimal-0.5.1-H3X57wSTHjwGTtZt62YXYD
license: BSD-3-Clause
copyright: Paul Johnson, 2013, 2018.
maintainer: paul@cogito.org.uk
author: Paul Johnson
stability: beta
homepage: https://github.com/PaulJohnson/Haskell-Decimal
synopsis: Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.
category: Math
abi: ba7e5f1d6b27ab96d3cc597a6df3fbcb
exposed: True
exposed-modules:
    Data.Decimal
import-dirs: /usr/lib/ghc-8.4.3/site-local/Decimal-0.5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/Decimal-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/Decimal-0.5.1
hs-libraries: HSDecimal-0.5.1-H3X57wSTHjwGTtZt62YXYD
depends:
    base-4.11.1.0 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html: /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-decimal-0.5.1-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Decimal
version: 0.5.1
id: Decimal-0.5.1-5riQdgZYPdS5MFHuTVF1ol
key: Decimal-0.5.1-5riQdgZYPdS5MFHuTVF1ol
license: BSD-3-Clause
copyright: Paul Johnson, 2013, 2018.
maintainer: paul@cogito.org.uk
author: Paul Johnson
stability: beta
homepage: https://github.com/PaulJohnson/Haskell-Decimal
synopsis: Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.
category: Math
abi: 82fdcf518fdcc6eb36c2a282af52784e
exposed: True
exposed-modules:
    Data.Decimal
import-dirs: /usr/lib/ghc-8.4.3/site-local/Decimal-0.5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/Decimal-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/Decimal-0.5.1
hs-libraries: HSDecimal-0.5.1-5riQdgZYPdS5MFHuTVF1ol
depends:
    base-4.11.1.0 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html: /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
